==> opentoonz-dmo_1.5.0.orig.tar.xz: opentoonz-1.5.0/toonz/sources/translations/french/image.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AviWriterProperties</name>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1182"/>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1183"/>
        <source>Uncompressed</source>
        <translation>Non compressée</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="257"/>
        <source>Scale</source>
        <translation>Échelle</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="258"/>
        <source>Looping</source>
        <translation>Boucle</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="259"/>
        <source>Generate Palette</source>
        <translation>Générer la palette</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="234"/>
        <source>Quality</source>
        <translation>Qualité</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="235"/>
        <source>Scale</source>
        <translation>Échelle</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <location filename="../../image/png/tiio_png.cpp" line="738"/>
        <source>Alpha Channel</source>
        <translation>Canal alpha</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="177"/>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>Le délai d&apos;attente de FFMPEG est dépassé.
Veuillez vérifier que le fichier ne comporte par d&apos;erreur.
Si le fichier ne se lit pas ou est incomplet,
veuillez essayer d&apos;augmenter le délai d&apos;attente de FFMPEG dans les préférences.</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1231"/>
        <source>Bits Per Pixel</source>
        <translation>Bits par pixel</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1232"/>
        <source>24 bits</source>
        <translation>24 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1233"/>
        <source>32 bits</source>
        <translation>32 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1234"/>
        <source>48 bits</source>
        <translation>48 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1235"/>
        <source>64 bits</source>
        <translation>64 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1236"/>
        <source>8 bits (Greyscale)</source>
        <translation>8 bits (Niveaux de gris)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1237"/>
        <source>Endianess</source>
        <translation>Endianess</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1238"/>
        <source>Big Endian</source>
        <translation>Gros Endian</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1239"/>
        <source>Little Endian</source>
        <translation>Petit Endian</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1240"/>
        <source>RLE-Compressed</source>
        <translation>Compressé RLE</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="313"/>
        <source>Top Padding</source>
        <translation>Marge interne haute</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="314"/>
        <source>Bottom Padding</source>
        <translation>Marge interne basse</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="315"/>
        <source>Left Padding</source>
        <translation>Marge interne gauche</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="316"/>
        <source>Right Padding</source>
        <translation>Marge interne droite</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="317"/>
        <source>Scale</source>
        <translation>Échelle</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="318"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="319"/>
        <source>Grid</source>
        <translation>Grille</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="320"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="321"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="322"/>
        <source>Individual</source>
        <translation>Individuel</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="323"/>
        <source>Trim Empty Space</source>
        <translation>Effacer l&apos;espace vide</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1969"/>
        <source>Stroke Mode</source>
        <translation>Type de ligne</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1970"/>
        <source>Outline Quality</source>
        <translation>Qualité des contours</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1971"/>
        <source>Centerline</source>
        <translation>Ligne centrale</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1972"/>
        <source>Outline</source>
        <translation>Contour</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1973"/>
        <source>High</source>
        <translation>Élevée</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1974"/>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1975"/>
        <source>Low</source>
        <translation>Basse</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="523"/>
        <source>Bits Per Pixel</source>
        <translation>Bits par pixel</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="524"/>
        <source>16 bits</source>
        <translation>16 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="525"/>
        <source>24 bits</source>
        <translation>24 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="526"/>
        <source>32 bits</source>
        <translation>32 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="527"/>
        <source>Compression</source>
        <translation>Compression</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="730"/>
        <source>Byte Ordering</source>
        <translation>Ordre des octets</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="731"/>
        <source>Compression Type</source>
        <translation>Type de compression</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="732"/>
        <source>Bits Per Pixel</source>
        <translation>Bits par pixel</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="733"/>
        <source>24(RGB)</source>
        <translation>24 (RVB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="734"/>
        <source>48(RGB)</source>
        <translation>48 (RVB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="735"/>
        <source> 1(BW)</source>
        <translation> 1 (NB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="736"/>
        <source> 8(GREYTONES)</source>
        <translation> 8 (NIVEAUX DE GRIS)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="737"/>
        <source>32(RGBM)</source>
        <translation>32 (RVBM)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="738"/>
        <source>64(RGBM)</source>
        <translation>64 (RVBM)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="739"/>
        <source>Orientation</source>
        <translation>Orientation</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="740"/>
        <source>Top Left</source>
        <translation>En haut à gauche</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="741"/>
        <source>Top Right</source>
        <translation>En haut à droite</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="742"/>
        <source>Bottom Right</source>
        <translation>En bas à droite</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="743"/>
        <source>Bottom Left</source>
        <translation>En bas à gauche</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="744"/>
        <source>Left Top</source>
        <translation>En haut à gauche</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="745"/>
        <source>Left Bottom</source>
        <translation>En bas à gauche</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="746"/>
        <source>Right Top</source>
        <translation>En haut à droite</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="747"/>
        <source>Right Bottom</source>
        <translation>En bas à droite</translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="235"/>
        <source>Quality</source>
        <translation>Qualité</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="236"/>
        <source>Scale</source>
        <translation>Échelle</translation>
    </message>
</context>
</TS>

==> opentoonz-dmo_1.7.1.1.orig.tar.xz: opentoonz-1.7.1.1/toonz/sources/translations/french/image.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AviWriterProperties</name>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1182"/>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1183"/>
        <source>Uncompressed</source>
        <translation>Non compressée</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="257"/>
        <source>Scale</source>
        <translation>Échelle</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="258"/>
        <source>Looping</source>
        <translation>Boucle</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="259"/>
        <source>Generate Palette</source>
        <translation>Générer la palette</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="234"/>
        <source>Quality</source>
        <translation>Qualité</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="235"/>
        <source>Scale</source>
        <translation>Échelle</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <location filename="../../image/png/tiio_png.cpp" line="738"/>
        <source>Alpha Channel</source>
        <translation>Canal alpha</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="177"/>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>Le délai d&apos;attente de FFMPEG est dépassé.
Veuillez vérifier que le fichier ne comporte par d&apos;erreur.
Si le fichier ne se lit pas ou est incomplet,
veuillez essayer d&apos;augmenter le délai d&apos;attente de FFMPEG dans les préférences.</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1231"/>
        <source>Bits Per Pixel</source>
        <translation>Bits par pixel</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1232"/>
        <source>24 bits</source>
        <translation>24 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1233"/>
        <source>32 bits</source>
        <translation>32 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1234"/>
        <source>48 bits</source>
        <translation>48 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1235"/>
        <source>64 bits</source>
        <translation>64 bits</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1236"/>
        <source>8 bits (Greyscale)</source>
        <translation>8 bits (Niveaux de gris)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1237"/>
        <source>Endianness</source>
        <translation>Endianness</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1238"/>
        <source>Big Endian</source>
        <translation>Gros Endian</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1239"/>
        <source>Little Endian</source>
        <translation>Petit Endian</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1240"/>
        <source>RLE-Compressed</source>
        <translation>Compressé RLE</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="313"/>
        <source>Top Padding</source>
        <translation>Marge interne haute</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="314"/>
        <source>Bottom Padding</source>
        <translation>Marge interne basse</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="315"/>
        <source>Left Padding</source>
        <translation>Marge interne gauche</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="316"/>
        <source>Right Padding</source>
        <translation>Marge interne droite</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="317"/>
        <source>Scale</source>
        <translation>Échelle</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="318"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="319"/>
        <source>Grid</source>
        <translation>Grille</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="320"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="321"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="322"/>
        <source>Individual</source>
        <translation>Individuel</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="323"/>
        <source>Trim Empty Space</source>
        <translation>Effacer l&apos;espace vide</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1969"/>
        <source>Stroke Mode</source>
        <translation>Type de ligne</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1970"/>
        <source>Outline Quality</source>
        <translation>Qualité des contours</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1971"/>
        <source>Centerline</source>
        <translation>Ligne centrale</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1972"/>
        <source>Outline</source>
        <translation>Contour</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1973"/>
        <source>High</source>
        <translation>Élevée</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1974"/>
        <source>Medium</source>
        <translation>Moyenne</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1975"/>
        <source>Low</source>
        <translation>Basse</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="523"/>
        <source>Bits Per Pixel</source>
        <translation>Bits par pixel</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="524"/>
        <source>16 bits</source>
        <translation>16 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="525"/>
        <source>24 bits</source>
        <translation>24 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="526"/>
        <source>32 bits</source>
        <translation>32 bits</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="527"/>
        <source>Compression</source>
        <translation>Compression</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="730"/>
        <source>Byte Ordering</source>
        <translation>Ordre des octets</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="731"/>
        <source>Compression Type</source>
        <translation>Type de compression</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="732"/>
        <source>Bits Per Pixel</source>
        <translation>Bits par pixel</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="733"/>
        <source>24(RGB)</source>
        <translation>24 (RVB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="734"/>
        <source>48(RGB)</source>
        <translation>48 (RVB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="735"/>
        <source> 1(BW)</source>
        <translation> 1 (NB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="736"/>
        <source> 8(GREYTONES)</source>
        <translation> 8 (NIVEAUX DE GRIS)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="737"/>
        <source>32(RGBM)</source>
        <translation>32 (RVBM)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="738"/>
        <source>64(RGBM)</source>
        <translation>64 (RVBM)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="739"/>
        <source>Orientation</source>
        <translation>Orientation</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="740"/>
        <source>Top Left</source>
        <translation>En haut à gauche</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="741"/>
        <source>Top Right</source>
        <translation>En haut à droite</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="742"/>
        <source>Bottom Right</source>
        <translation>En bas à droite</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="743"/>
        <source>Bottom Left</source>
        <translation>En bas à gauche</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="744"/>
        <source>Left Top</source>
        <translation>En haut à gauche</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="745"/>
        <source>Left Bottom</source>
        <translation>En bas à gauche</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="746"/>
        <source>Right Top</source>
        <translation>En haut à droite</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="747"/>
        <source>Right Bottom</source>
        <translation>En bas à droite</translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="235"/>
        <source>Quality</source>
        <translation>Qualité</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="236"/>
        <source>Scale</source>
        <translation>Échelle</translation>
    </message>
</context>
</TS>
